@@ -19,6 +19,7 @@
 
 #include "eckit/config/Configuration.h"
 #include "eckit/config/Configured.h"
+#include "eckit/types/Types.h"
 
 namespace eckit {
 
@@ -44,12 +45,14 @@ public: // methods
     LocalConfiguration& set(const std::string &name, bool value);
     LocalConfiguration& set(const std::string &name, int value);
     LocalConfiguration& set(const std::string &name, long value);
+    LocalConfiguration& set(const std::string &name, long long value);
     LocalConfiguration& set(const std::string& name, size_t value);
     LocalConfiguration& set(const std::string &name, float value);
     LocalConfiguration& set(const std::string &name, double value);
 
     LocalConfiguration& set(const std::string& name, const std::vector<int>& value);
     LocalConfiguration& set(const std::string& name, const std::vector<long>& value);
+    LocalConfiguration& set(const std::string& name, const std::vector<long long>& value);
     LocalConfiguration& set(const std::string& name, const std::vector<size_t>& value);
     LocalConfiguration& set(const std::string& name, const std::vector<float>& value);
     LocalConfiguration& set(const std::string& name, const std::vector<double>& value);
@@ -74,6 +77,8 @@ private:
 
 };
 
+template <> struct VectorPrintSelector<LocalConfiguration> { typedef VectorPrintSimple selector; };
+
 //----------------------------------------------------------------------------------------------------------------------
 
 } // namespace eckit
