@@ -151,7 +151,6 @@ public: // methods
 
 private: // methods
 
-
     bool get(const key_t& key, PathName& path) const;
 
     PathName stage(const key_t& key, const PathName& root) const;
@@ -187,32 +186,31 @@ CacheManager<Traits>::CacheManager(const std::string& loaderName,
 
     for (std::vector<std::string>::const_iterator i = v.begin(); i != v.end(); ++i) {
 
-        std::string path = *i;
-
         // entries with e.g. {CWDFS}/cache will be expanded with PathExpander factory CWDFS
 
-        PathName p = PathExpander::expand(path);
+        PathName p = PathExpander::expand(*i);
 
-        if (p.exists()) {
-            roots_.push_back(p);
-        }
-        else {
+        if (not p.exists()) {
             Log::warning() << "CACHE-MANAGER " << Traits::name() << ", " << p << " does not exist" << std::endl;
             try {
-                AutoUmask umask(0);
-                p.mkdir(0777);
-                Log::warning() << "CACHE-MANAGER " << Traits::name() << ", " << p << " created" << std::endl;
-            }
-            catch ( FailedSystemCall& e ) {
-                // ignore
-            }
-            if (p.exists()) {
-                roots_.push_back(p);
+                if(writable(p.dirName())) {
+                    AutoUmask umask(0);
+                    p.mkdir(0777);
+                    Log::warning() << "CACHE-MANAGER " << Traits::name() << ", " << p << " created" << std::endl;
+                }
+                else {
+                    Log::debug<LibEcKit>() << "CACHE-MANAGER " << Traits::name() << ", " << p.dirName() << " not writable" << std::endl;
+                }
             }
+            catch ( FailedSystemCall& ) { /* ignore */ }
+        }
+
+        if (p.exists()) { // test again, we may have just created it
+            roots_.push_back(p);
         }
     }
 
-    Log::debug<LibEcKit>() << "CACHE-MANAGER " << Traits::name() << ", roots defined and found: " << roots_ << std::endl;
+    Log::debug<LibEcKit>() << "CACHE-MANAGER " << Traits::name() << ", roots defined and found or created: " << roots_ << std::endl;
 }
 
 template<class Traits>
