@@ -42,9 +42,9 @@ public: // methods
 
     /// Destructor
     /// @throws nothing
-    virtual ~Exception() throw();
+    virtual ~Exception() noexcept;
 
-    virtual const char *what() const throw() {  return what_.c_str(); }
+    virtual const char *what() const noexcept {  return what_.c_str(); }
     virtual bool retryOnServer() const        { return false; }
     virtual bool retryOnClient() const        { return false; }
     virtual bool terminateApplication() const { return false; }
@@ -283,7 +283,7 @@ inline void PanicNoLog(int code, const char *msg, const CodeLocation& loc)
 /// For compatibility
 class OutOfMemory : public Exception {
     virtual bool terminateApplication() const { return true; }
-    virtual const char *what() const throw() {  return "OutOfMemory"; }
+    virtual const char *what() const noexcept {  return "OutOfMemory"; }
 public:
     OutOfMemory();
 
