@@ -1,9 +1,9 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
- * 
+ * (C) Copyright 1996- ECMWF.
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
@@ -18,6 +18,7 @@
 #include <map>
 
 #include "eckit/memory/NonCopyable.h"
+#include "eckit/types/Types.h"
 
 namespace eckit {
 
@@ -27,12 +28,12 @@ class PathExpander : private eckit::NonCopyable {
 
 public: // methods
 
-    static std::string expand(const std::string& key, const std::string& path);
-
-    virtual std::string expand(const std::string& path) const = 0;
+    static std::string expand(const std::string& path);
 
 protected: // methods
 
+    virtual void expand(const std::string& var, const std::string& path, eckit::StringDict& vars) const = 0;
+
     PathExpander(const std::string&);
 
     virtual ~PathExpander();
