@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
+ * (C) Copyright 1996- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -12,19 +12,14 @@
 
 #include "eckit/filesystem/TmpFile.h"
 
-//-----------------------------------------------------------------------------
 
 namespace eckit {
 
-//-----------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
-static PathName tmp()
-{
-    const char *tmpdir = ::getenv("TMPDIR");
-	if(!tmpdir)
-	{
-        tmpdir = "/tmp";
-    }
+static PathName tmp() {
+    const char* tmpdir = ::getenv("TMPDIR");
+    if (!tmpdir) { tmpdir = "/tmp"; }
 
     long max = pathconf(tmpdir, _PC_PATH_MAX);
     char path[max];
@@ -41,16 +36,12 @@ static PathName tmp()
 }
 
 
-TmpFile::TmpFile(): PathName(tmp())
-{
-}
+TmpFile::TmpFile() : PathName(tmp()) {}
 
-TmpFile::~TmpFile()
-{
+TmpFile::~TmpFile() {
     unlink();
 }
 
-//-----------------------------------------------------------------------------
-
-} // namespace eckit
+//----------------------------------------------------------------------------------------------------------------------
 
+}  // namespace eckit
