@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
+ * (C) Copyright 1996- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -8,34 +8,34 @@
  * does it submit to any jurisdiction.
  */
 
-#include "eckit/eckit.h"
+#include <stdio.h>
 
 #include "eckit/filesystem/PathName.h"
+#include "eckit/exception/Exceptions.h"
 #include "eckit/io/StdFile.h"
 
-
-//-----------------------------------------------------------------------------
-
 namespace eckit {
 
-//-----------------------------------------------------------------------------
-
-StdFile::StdFile(const PathName& name,const std::string& mode)
+StdFile::StdFile(const PathName& name, const std::string& mode) :
+    file_(0)
 {
-	file_ = ::fopen(name.localPath(),mode.c_str());
+    file_ = ::fopen(name.localPath(), mode.c_str());
 
-	if(file_ == 0)
+    if(file_ == 0)
 		throw CantOpenFile(name);
 }
 
-StdFile::~StdFile()
-{
-	if(file_)
-		if(fclose(file_))
-			throw FailedSystemCall("fclose");
+StdFile::~StdFile() {
+    ASSERT_MSG(!isOpen(), "StdFile hasn't been closed before destruction");
 }
 
-//-----------------------------------------------------------------------------
+void StdFile::close() noexcept(false) {
+    if(isOpen()) {
+        if(fclose(file_))
+            throw FailedSystemCall("fclose");
+    }
+    file_ = 0;
+}
 
 } // namespace eckit
 
