@@ -1,15 +1,15 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
- * 
+ * (C) Copyright 1996- ECMWF.
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
 
-// File Stdio/FileHandle.h
-// Piotr Kuchta - ECMWF April 09
+/// @author Piotr Kuchta
+/// @date   April 09
 
 #ifndef eckit_filesystem_StdFileHandle_h
 #define eckit_filesystem_StdFileHandle_h
@@ -18,27 +18,18 @@
 #include "eckit/io/DataHandle.h"
 
 
-//-----------------------------------------------------------------------------
 
 namespace eckit {
 
-//-----------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 class StdFileHandle : public DataHandle {
 public:
 
-// -- Contructors
-
 	StdFileHandle(FILE *);
 
-// -- Destructor
-
 	~StdFileHandle();
 
-// -- Overridden methods
-
-	// From DataHandle
-
     virtual Length openForRead();
     virtual void openForWrite(const Length&);
     virtual void openForAppend(const Length&);
@@ -48,25 +39,15 @@ public:
 	virtual void   close();
 	virtual void   print(std::ostream&) const;
 
-	// From Streamable
-
 	virtual void encode(Stream&) const;
 
-// -- Class methods
+private: // members
 
-
-private:
-
-// -- Members
-
-	FILE* f_;
-
-// -- Class members
+    FILE* f_;
 
 };
 
-
-//-----------------------------------------------------------------------------
+//----------------------------------------------------------------------------------------------------------------------
 
 } // namespace eckit
 
