@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
+ * (C) Copyright 1996- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -8,14 +8,16 @@
  * does it submit to any jurisdiction.
  */
 
+#include <stdio.h>
+#include <string>
+
 #include "eckit/exception/Exceptions.h"
 #include "eckit/io/StdPipe.h"
 
 namespace eckit {
 
-//----------------------------------------------------------------------------------------------------------------------
-
-StdPipe::StdPipe(const std::string& name,const std::string& mode)
+StdPipe::StdPipe(const std::string& name,const std::string& mode) :
+    file_(0)
 {
 	file_ = ::popen(name.c_str(),mode.c_str());
 
@@ -23,16 +25,18 @@ StdPipe::StdPipe(const std::string& name,const std::string& mode)
 		throw CantOpenFile(name);
 }
 
-StdPipe::~StdPipe()
-{
-    if (file_) {
+StdPipe::~StdPipe() {
+    ASSERT_MSG(!isOpen(), "StdPipe hasn't been closed before destruction");
+}
+
+void StdPipe::close() noexcept(false) {
+    if (isOpen()) {
         if (::pclose(file_) == -1) {
             throw FailedSystemCall("pclose");
         }
     }
+    file_ = 0;
 }
 
-//----------------------------------------------------------------------------------------------------------------------
-
 } // namespace eckit
 
