@@ -1,9 +1,9 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
- * 
+ * (C) Copyright 1996- ECMWF.
+ *
  * This software is licensed under the terms of the Apache Licence Version 2.0
- * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
- * In applying this licence, ECMWF does not waive the privileges and immunities 
+ * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+ * In applying this licence, ECMWF does not waive the privileges and immunities
  * granted to it by virtue of its status as an intergovernmental organisation nor
  * does it submit to any jurisdiction.
  */
@@ -34,7 +34,7 @@ std::ostream& operator<<(std::ostream& s,const ETA&  sec)
     long hour = n / (60 * 60); n %= (60 * 60);
     long minutes = n / 60 ; n %= 60 ;
 
-    s << hour << ':' << std::setfill('0') << std::setw(2) << minutes << ':'  << std::setfill('0') << std::setw(2) << n;
+    s << hour << ':' << std::setfill('0') << std::setw(2) << minutes << ':'  << std::setfill('0') << std::setw(2) << n << std::setfill(' ');
 
 	return s;
 }
