@@ -35,6 +35,7 @@ struct Timing {
     Timing(double elapsed, double cpu, size_t updates): elapsed_(elapsed), cpu_(cpu), updates_(updates) {}
     Timing(Timer& timer): elapsed_(timer.elapsed()), cpu_(timer.elapsed_cpu()), updates_(1) {}
     Timing& operator+=(const Timing&);
+    Timing& operator-=(const Timing&);
     Timing operator-(const Timing&) const;
     Timing& operator/=(size_t);
 };
@@ -62,10 +63,13 @@ class Statistics {
   public:
     static void reportUnit(std::ostream& out, const char* title, const char* unit, double value, const char* indent = "", bool always=false);
     static void reportRate(std::ostream& out, const char* title, unsigned long long value, const char* indent = "", bool always=false);
+    static void reportRate(std::ostream& out, const std::string& title, size_t bytes, double elapsed, const char* indent = "", bool always=false);
     static void reportCount(std::ostream& out, const char* title, size_t value, const char* indent = "", bool always=false);
     static void reportBytes(std::ostream& out, const char* title, unsigned long long value, const char* indent = "", bool always=false);
+    static void reportBytesStats(std::ostream& out, const std::string& title, size_t count, size_t bytes, size_t sumsquared, const char* indent = "", bool always=false);
     static void reportTime(std::ostream& out, const char* title, const Timing& value, const char* indent = "", bool always=false);
     static void reportTime(std::ostream& out, const char* title, double value, const char* indent = "", bool always=false);
+    static void reportTimeStats(std::ostream& out, const std::string& title, size_t count, double sum_times, double sum_times_squared, const char* indent = "", bool always=false);
     static Timer timer_;
 };
 
