@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
+ * (C) Copyright 1996- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -43,6 +43,9 @@ void setCommDefault(const char* name);
 /// Register a communicator comming from Fortran code
 void addComm(const char* name, int comm);
 
+/// Register an existing communicator
+void addComm(const char* name, Comm* comm);
+
 /// Check if a communicator is registered
 bool hasComm(const char* name);
 
@@ -81,13 +84,16 @@ public:  // methods
     /// @brief MPI barrier for this communicator
     virtual void barrier() const = 0;
 
+    /// @brief MPI non-blocking barrier for this communicator
+    virtual Request iBarrier() const = 0;
+
     /// @brief MPI abort for this communicator
     virtual void abort(int errorcode = -1) const = 0;
 
     /// @brief Wait for Request to be completed, ignoring the return status
     virtual Status wait(Request&) const = 0;
 
-    /// @brief Probe for incomming messages
+    /// @brief Probe for incoming messages (blocking)
     virtual Status probe(int source, int tag) const = 0;
 
     virtual int anySource() const = 0;
@@ -298,6 +304,9 @@ public:  // methods
     ///
 
     virtual eckit::SharedBuffer broadcastFile( const eckit::PathName& filepath, size_t root ) const = 0;
+    
+    /// @brief Split the communicator based on color & give the new communicator a name
+    virtual Comm & split( int color, const std::string & name ) const = 0;
 
     /// @brief The communicator
     virtual int communicator() const = 0;
@@ -345,6 +354,7 @@ public:  // methods
 
       virtual Request iSend(const void* send, size_t count, Data::Code datatype, int dest, int tag) const = 0;
 
+
 private: // methods
 
     virtual void print(std::ostream&) const = 0;
