@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
+ * (C) Copyright 1996- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -8,11 +8,16 @@
  * does it submit to any jurisdiction.
  */
 
+#include "eckit/mpi/Parallel.h"
 #include "eckit/mpi/ParallelRequest.h"
 
 namespace eckit {
 namespace mpi {
 
+
+void MPICall(int code, const char* mpifunc, const eckit::CodeLocation& loc);
+#define MPI_CALL(a) MPICall(a,#a,Here())
+
 //----------------------------------------------------------------------------------------------------------------------
 
 ParallelRequest::ParallelRequest() {
@@ -30,6 +35,12 @@ int ParallelRequest::request() const {
     return MPI_Request_c2f(request_);
 }
 
+bool ParallelRequest::test() {
+    int requestCompleted;
+    MPI_CALL( MPI_Test(&request_, &requestCompleted, MPI_STATUS_IGNORE) );
+    return requestCompleted;
+}
+
 //----------------------------------------------------------------------------------------------------------------------
 
 } // namespace mpi
