@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
+ * (C) Copyright 1996- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,7 +14,7 @@
 #include "eckit/os/System.h"
 #include "eckit/types/Types.h"
 
-#if defined(EC_HAVE_DLFCN_H) && defined(EC_HAVE_DLADDR)
+#if defined(ECKIT_HAVE_DLFCN_H) && defined(ECKIT_HAVE_DLADDR)
 
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
