@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
+ * (C) Copyright 1996- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -33,8 +33,7 @@ public: // methods
 
     virtual eckit::LocalPathName executablePath() const;
 
-    virtual size_t memoryAllocated() const;
-    virtual Mem memoryUsage() const;
+    virtual MemoryInfo memoryUsage() const;
 
 protected: // methods
 
