@@ -197,6 +197,13 @@ void TxnLog<T>::end(T& event, bool backup)
     path.unlink();
 }
 
+template<class T>
+bool TxnLog<T>::exists(T& event)
+{
+    PathName path = name(event);
+    return path.exists();
+}
+
 template<class T>
 class RecoverThread : public Thread {
     TxnArray& nextID_;
