@@ -9,15 +9,16 @@
  */
 
 #include "eckit/types/Fraction.h"
-#include "eckit/exception/Exceptions.h"
-#include "eckit/parser/Tokenizer.h"
-#include "eckit/utils/Translator.h"
-#include "eckit/serialisation/Stream.h"
-#include "eckit/utils/MD5.h"
 
 #include <cmath>
 #include <limits>
 
+#include "eckit/exception/Exceptions.h"
+#include "eckit/parser/Tokenizer.h"
+#include "eckit/serialisation/Stream.h"
+#include "eckit/utils/MD5.h"
+#include "eckit/utils/Translator.h"
+
 //-----------------------------------------------------------------------------
 
 namespace eckit {
@@ -134,6 +135,15 @@ Fraction::Fraction(double x) {
     bottom_ = bottom;
 }
 
+Fraction::Fraction(double n, const Fraction& precision) {
+    value_type bottom = precision.inverse().integralPart();
+    value_type top = value_type(std::round(bottom * n));
+
+    Fraction f(top, bottom);
+    top_ = f.top_;
+    bottom_ = f.bottom_;
+}
+
 Fraction::Fraction(const std::string& s) {
     static Tokenizer parse("/");
 
@@ -166,6 +176,10 @@ Fraction::Fraction(const char* c) {
     bottom_ = f.bottom_;
 }
 
+Fraction Fraction::abs(const Fraction& f) {
+    return { f.top_ < 0 ? -f.top_ : f.top_, f.bottom_ };
+}
+
 void Fraction::print(std::ostream& out) const {
     if (bottom_ == 1) {
         out << top_;
@@ -183,12 +197,20 @@ Fraction::operator value_type() const {
     throw eckit::SeriousBug(oss.str());
 }
 
+eckit::Fraction Fraction::inverse() const {
+    if (top_ == 0) {
+        std::ostringstream oss;
+        oss << "Cannot compute inverse of " << *this << std::endl;
+        throw eckit::BadValue(oss.str());
+    }
+    return { bottom_, top_ };
+}
+
 void Fraction::hash(MD5& md5) const {
     md5 << top_;
     md5 << bottom_;
 }
 
-
 void Fraction::encode(Stream& s) const {
     s << top_;
     s << bottom_;
@@ -199,12 +221,11 @@ void Fraction::decode(Stream& s) {
     s >> bottom_;
 }
 
-//----------------------------------------------------------------------------------------------------------------------
-
+//-----------------------------------------------------------------------------
 
 inline Fraction::value_type mul(bool& overflow, Fraction::value_type a, Fraction::value_type b) {
 
-    if(overflow) { return Fraction::value_type(); }
+    if (overflow) { return Fraction::value_type(); }
 
     if (b != 0) {
         overflow = std::abs(a) > std::numeric_limits<Fraction::value_type>::max() / std::abs(b);
@@ -215,10 +236,10 @@ inline Fraction::value_type mul(bool& overflow, Fraction::value_type a, Fraction
 
 inline Fraction::value_type add(bool& overflow, Fraction::value_type a, Fraction::value_type b) {
 
-    if(overflow) { return Fraction::value_type(); }
+    if (overflow) { return Fraction::value_type(); }
 
     overflow = b > 0 ? a > std::numeric_limits<Fraction::value_type>::max() - b
-                     : a < std::numeric_limits<Fraction::value_type>::lowest() - b;
+               : a < std::numeric_limits<Fraction::value_type>::lowest() - b;
 
     return a + b;
 }
@@ -335,6 +356,125 @@ bool Fraction::operator>=(const Fraction& other) const {
     return result;
 }
 
+//-----------------------------------------------------------------------------
+
+
+Fraction Fraction::fromString(const std::string& s) {
+
+    long numerator = 0;
+    long denumerator = 1;
+    int sgn = 1;
+    size_t err = 0;
+    bool decimal = false;
+
+    for (size_t i = 0; i < s.length(); ++i) {
+
+        switch (s[i]) {
+        case '-':
+            if (i != 0) {
+                err++;
+            }
+            sgn = -1;
+            break;
+
+        case '.':
+            if (decimal) {
+                err++;
+            }
+            decimal = true;
+            break;
+
+        case '0':
+        case '1':
+        case '2':
+        case '3':
+        case '4':
+        case '5':
+        case '6':
+        case '7':
+        case '8':
+        case '9':
+            numerator *= 10;
+            numerator += s[i] - '0';
+            if (decimal) {
+                denumerator *= 10;
+            }
+            break;
+
+        default:
+            break;
+        }
+
+    }
+
+    if (err) {
+        throw eckit::UserError("Fraction::fromString: invalid value [" + s + "]");
+    }
+
+    return eckit::Fraction(sgn * numerator, denumerator);
+}
+
+Fraction Fraction::stableVersion(size_t max) const {
+    Fraction x(*this);
+
+    size_t n = 0;
+    for (;;) {
+        Fraction y = Fraction(double(x));
+        if (y == x) {
+//             std::cout << "STABLE =========== " << n << " "
+//             << double(*this) << " " << *this
+// << " -> " << double(x) << " " << x <<
+//             std::endl;
+            break;
+        }
+        x = y;
+        n++;
+        if (n >= max) {
+            std::ostringstream oss;
+            oss << "Fraction::stableVersion("
+                << *this
+                << ") did not converge after "
+                << max
+                << " iterations. Last value: "
+                << x;
+            throw eckit::SeriousBug(oss.str());
+        }
+    }
+
+    return x;
+}
+
+//-----------------------------------------------------------------------------
+
+template<>
+bool Fraction::operator==(double other) const {
+    return double(*this) == other;
+}
+
+template<>
+bool Fraction::operator<(double other) const {
+    return double(*this) <  other;
+}
+
+template<>
+bool Fraction::operator<=(double other) const {
+    return double(*this) <= other;
+}
+
+template<>
+bool Fraction::operator!=(double other) const {
+    return double(*this) != other;
+}
+
+template<>
+bool Fraction::operator>(double other) const {
+    return double(*this) >  other;
+}
+
+template<>
+bool Fraction::operator>=(double other) const {
+    return double(*this) >= other;
+}
 
 } // namespace eckit
 
