@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
+ * (C) Copyright 1996- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -48,7 +48,7 @@ void CgiResource::GET(std::ostream& s,Url& url)
         url.cgiParam(cmd,' ');
 	}
 
-    StdPipe pipe(cmd.str(),"r");
+    StdPipe pipe(cmd.str(),"r");  AutoCloser<StdPipe> closer(pipe);
 	char line[1024];
 
 	s << HttpBuf::dontEncode;
