@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
+ * (C) Copyright 1996- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -14,11 +14,11 @@
 #include "eckit/web/HttpBuf.h"
 #include "eckit/web/Url.h"
 
-//-----------------------------------------------------------------------------
+
 
 namespace eckit {
 
-//-----------------------------------------------------------------------------
+
 
 FileResource::FileResource():
 	HtmlResource("/html")
@@ -33,20 +33,20 @@ void FileResource::GET(std::ostream& s,Url& url)
 {
 	eckit::PathName path("~/http/" + url.name());
 
-	StdFile file(path,"r");
+    eckit::AutoStdFile f(path,"r");
 	char line[1024];
 
 	s << HttpBuf::dontEncode;
 
-	while(fgets(line,sizeof(line),file))
+    while(fgets(line,sizeof(line), f)) {
 		s << line;
+    }
 
 	s << HttpBuf::doEncode;
 }
 
 static FileResource fileResourceInstance;
 
-//-----------------------------------------------------------------------------
 
 } // namespace eckit
 
