@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
+ * (C) Copyright 1996- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -18,7 +18,7 @@ namespace eckit_test {
 
 //-----------------------------------------------------------------------------
 
-AnyKeyParams::AnyKeyParams(std::string payload) : payload_(payload) {}
+AnyKeyParams::AnyKeyParams(const std::string& payload) : payload_(payload) {}
 
 AnyKeyParams::AnyKeyParams(Stream& s) {
   s >> payload_;
