@@ -1,9 +1,18 @@
-# No module environment on the Mac
+#!/bin/bash
+
 [[ $(uname) == "Darwin" ]] && return
-# Initialise module environment if it is not
+
+# initialise module environment if it is not
 if [[ ! $(command -v module > /dev/null 2>&1) ]]; then
   . /usr/local/apps/module/init/bash
 fi
-module unload eccodes
+
 module unload grib_api
-module switch gnu clang/3.6.2
+module unload eccodes
+module unload emos
+module unload fftw
+module unload libemos
+
+module load cmake/3.10.2
+
+module switch gnu clang
