@@ -1,13 +1,16 @@
 #!/bin/bash
 
-# Initialise module environment if it is not
+# initialise module environment if it is not
 if [[ ! $(command -v module > /dev/null 2>&1) ]]; then
   . /usr/local/apps/module/init/bash
 fi
-# Unload modules not available for Intel
+
 module unload grib_api
 module unload eccodes
 module unload emos
 module unload fftw
 module unload libemos
+
+module load cmake/3.10.2
+
 module switch gnu intel/16.0.3
