@@ -1,5 +1,5 @@
 /*
- * (C) Copyright 1996-2017 ECMWF.
+ * (C) Copyright 1996- ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -26,14 +26,14 @@
 namespace metkit {
 namespace grib {
 
-//----------------------------------------------------------------------------------------------------------------------
 
 GribFile::GribFile(const eckit::PathName& path) :
     path_(path),
     file_(path_) {
 }
 
-GribFile::~GribFile() {
+GribFile::~GribFile() noexcept(false) {
+    file_.close();
 }
 
 GribHandle* GribFile::next() {
@@ -53,8 +53,6 @@ GribHandle* GribFile::next() {
     throw eckit::ReadError(msg.str(), Here());
 }
 
-//----------------------------------------------------------------------------------------------------------------------
-
 } // namespace grib
 } // namespace metkit
 
